==> payara-embedded-all-5.2020.4-sources.jar: fish/payara/notification/jms/JmsNotifierConfiguration.java <==
/*
 *
 * Copyright (c) 2016 Payara Foundation and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://github.com/payara/Payara/blob/master/LICENSE.txt
 * See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * The Payara Foundation designates this particular file as subject to the "Classpath"
 * exception as provided by the Payara Foundation in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package fish.payara.notification.jms;

import fish.payara.nucleus.notification.configuration.NotifierConfiguration;
import fish.payara.nucleus.notification.configuration.NotifierConfigurationType;
import fish.payara.nucleus.notification.configuration.NotifierType;
import org.jvnet.hk2.config.Attribute;
import org.jvnet.hk2.config.Configured;

import java.beans.PropertyVetoException;

/**
 * @author mertcaliskan
 */
@Configured
@NotifierConfigurationType(type = NotifierType.JMS)
public interface JmsNotifierConfiguration extends NotifierConfiguration {

    @Attribute(required = true)
    String getContextFactoryClass();
    void setContextFactoryClass(String value) throws PropertyVetoException;

    @Attribute(required = true)
    String getConnectionFactoryName();
    void setConnectionFactoryName(String value) throws PropertyVetoException;

    @Attribute(required = true)
    String getQueueName();
    void setQueueName(String value) throws PropertyVetoException;

    @Attribute(required = true)
    String getUrl();
    void setUrl(String value) throws PropertyVetoException;

    @Attribute
    String getUsername();
    void setUsername(String value) throws PropertyVetoException;

    @Attribute
    String getPassword();
    void setPassword(String value) throws PropertyVetoException;
}

==> payara-embedded-all-6.2023.6-sources.jar: fish/payara/notification/jms/JmsNotifierConfiguration.java <==
/*
 * Copyright (c) [2016-2020] Payara Foundation and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://github.com/payara/Payara/blob/master/LICENSE.txt
 * See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * The Payara Foundation designates this particular file as subject to the "Classpath"
 * exception as provided by the Payara Foundation in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package fish.payara.notification.jms;

import java.beans.PropertyVetoException;

import org.jvnet.hk2.config.Attribute;
import org.jvnet.hk2.config.Configured;

import fish.payara.internal.notification.PayaraNotifierConfiguration;

/**
 * @author mertcaliskan
 */
@Configured
public interface JmsNotifierConfiguration extends PayaraNotifierConfiguration {

    @Attribute(required = true)
    String getContextFactoryClass();
    void setContextFactoryClass(String value) throws PropertyVetoException;

    @Attribute(required = true)
    String getConnectionFactoryName();
    void setConnectionFactoryName(String value) throws PropertyVetoException;

    @Attribute(required = true)
    String getQueueName();
    void setQueueName(String value) throws PropertyVetoException;

    @Attribute(required = true)
    String getUrl();
    void setUrl(String value) throws PropertyVetoException;

    @Attribute
    String getUsername();
    void setUsername(String value) throws PropertyVetoException;

    @Attribute
    String getPassword();
    void setPassword(String value) throws PropertyVetoException;
}
